OC.L10N.register(
    "core",
    {
    "Sunday" : "Ням",
    "Monday" : "Даваа",
    "Tuesday" : "Мягмар",
    "Wednesday" : "Лхагва",
    "Thursday" : "Пүрэв",
    "Friday" : "Баасан",
    "Saturday" : "Бямба",
    "Settings" : "Тохиргоо",
    "Remove" : "Устгах",
    "Password" : "Нууц үг",
    "Save" : "Хадгалах",
    "Share" : "Түгээх",
    "Username" : "Хэрэглэгчийн нэр",
    "Edit" : "Засах",
    "Delete" : "Устгах",
    "Cancel" : "Цуцлах",
    "Error" : "Алдаа"
},
"nplurals=2; plural=(n != 1);");
